==> dl.php?src=linea21_1_6.zip: linea21/languages/es/lang_common.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules pour menu
 *  	*/
$lang['menu']['general'] = "Administración global";
$lang['menu']['theme'] = "Gestión de áreas temáticas";
$lang['menu']['scale'] = "Gestión de escalas";
$lang['menu']['level'] = "Gestión de niveles";
$lang['menu']['user'] = "Gestión de usuarios";
$lang['menu']['news'] = "Gestión de noticias";
$lang['menu']['page'] = "Pages manager"; // @todo translation
$lang['menu']['newsletter'] = "Gestión de boletines";
$lang['menu']['yellowpages'] = "Gestión del directorio";
$lang['menu']['workshop'] = "Gestión de grupos de trabajo";
$lang['menu']['publication'] = "Gestión de publicaciones";
$lang['menu']['sdi'] = "Gestión de indicadores";
$lang['menu']['project'] = "Gestión de proyectos";
$lang['menu']['forum'] = "Gestión de foros";
$lang['menu']['comment'] = "Gestión de comentarios";
$lang['menu']['item'] = "Item seleccionado";
$lang['menu']['search'] = "Buscar";
$lang['menu']['advancedsearch'] = "Búsqueda avanzada";
$lang['menu']['dashboard'] = "Gestión del panel de indicadores";
$lang['menu']['system'] = "Configuración del sistema";
$lang['menu']['plugins'] = "Plugins";
$lang['menu']['library'] = "Mediateca";

/*	nommage des modules
 *  	*/
$lang['name']['news_module'] = "noticias";
$lang['name']['publication_module'] = "publicación";
$lang['name']['det_publication_module'] = "apartado";
$lang['name']['workshop_module'] = "grupo de trabajo";
$lang['name']['workshoprep_module'] = "informe";
$lang['name']['workshoprepcon_module'] = "sub-informe";
$lang['name']['workshopcal_module'] = "calendario";
$lang['name']['workshopcom_module'] = "asunto";
$lang['name']['sdi_module'] = 'indicador';

/*	nommage header
 *  	*/
$lang['header']['title']= "Linea21, tu consola de administración";
$lang['header']['welcome']= "Bienvenido";
$lang['header']['deconnexion']= "Cerrar sesión";
$lang['header']['deconnexion_title']= "cerrar sesión";
$lang['header']['myaccount']="Mi cuenta";
$lang['header']['myaccount_title']="identificación/acceso a mi cuenta";
$lang['header']['goto_contents']="Ver contenidos";

$lang['admin']['console']="Back-office"; // @todo translation

/*	nommage chemin
 *  	*/
$lang['way']['home']= "Inicio";
$lang['recap']['title']="Resúmen";

/*	action bouton
 *  	*/
$lang['btn']['valid']= "validar";
$lang['btn']['save']= "guardar";
$lang['btn']['annul']= "cancelar";
$lang['btn']['preview']= "revisar valores";
$lang['btn']['read_more']= "→ Read more"; // @todo translation
/*	statut

*  	*/
$lang['statut']['draft']='borrador';
$lang['statut']['draftpdf']='privado';
$lang['statut']['published_on']="fecha de publicación";
$lang['statut']['archived_on']="fecha de modificación";
$lang['statut']['public']="Público";
$lang['statut']['E']="Eliminar";
$lang['statut']['AA']="Archivos privados";
$lang['statut']['PA']="Archivos públicos";
$lang['statut']['W']="Pendiente de ejecución";
$lang['statut']['C']="Cerrado";
$lang['statut']['U']="Usuario";
$lang['statut']['O']="Animador";
$lang['statut']['A']="Administrador";
$lang['statut']['pending']="pending"; // @todo translation

/*	Contact
 *  	*/
$lang['contact']['name']= "Name"; // @todo translation
$lang['contact']['email']="Email"; // @todo translation
$lang['contact']['subject']= "Subject"; // @todo translation
$lang['contact']['body']="Body"; // @todo translation
$lang['contact']['email_error']="<em>%s</em> is not a valid email."; // @todo translation
$lang['contact']['str_error']= "Please fill-up the field <em>%s</em>."; // @todo translation
$lang['contact']['message_sent']="Your message has been sent with success."; // @todo translation
$lang['contact']['contact_us']="Contact us"; // @todo translation

/*	divers
 *  	*/
$lang['divers']['yes']='si';
$lang['divers']['no']='no';
$lang['divers']['nc']='no consta';
$lang['divers']['none']='ninguno';
$lang['divers']['actions']='acciones';
$lang['divers']['no_comment']='sin comentarios';
$lang['divers']['comment']='comentario';
$lang['divers']['optional']='opcional';
$lang['divers']['nodata']='sin datos';
$lang['divers']['novisu']="sin imagen asociada";
$lang['divers']['see_visual']='ver imagen';
$lang['divers']['last_modify']="fecha de carga";
$lang['divers']['date_crea']="fecha de creación";
$lang['divers']['date_sup']="fecha de eliminación";
$lang['divers']['date_publi']="fecha de publicación";
$lang['divers']['sup_confirm']="Confirmar eliminación";
$lang['divers']['statut']="estado";
$lang['divers']['range']="rango";
$lang['divers']['query_result']="Resultado de la consulta";
$lang['divers']['record']="registro";
$lang['divers']['records']="registros";
$lang['divers']['version']="Consola de administración de Linea21: versión ".LINEA_VERSION;
$lang['divers']['select_choice']="-- Seleccionar de la lista--";
$lang['divers']['select_choice2']="-- Seleccionar --";
$lang['divers']['enlarge_photo']='ampliar imagen (hacer click)';
$lang['divers']['by']="por";
$lang['divers']['goto_archives']='Ver archivos';
$lang['divers']['goto_currentlist']='volver al menú principal';
$lang['divers']['page']='página';
$lang['divers']['seconds']='segundos';
$lang['divers']['back_public']='Ir al sitio web';
$lang['divers']['backpage']='Página anterior';
$lang['divers']['licence']='software bajo licencia de %s ';
$lang['divers']['select_all']='seleccionar todo';
$lang['divers']['modify']='Editar';
$lang['divers']['delete']='Eliminar';
$lang['divers']['permalink']='permalink';
$lang['divers']['404']="Esta página no existe!";
$lang['divers']['no_files']="no file"; // @todo translation
$lang['divers']['browse']="Browse ..."; // @todo translation
$lang['divers']['dl']="Download"; // @todo translation
$lang['divers']['up']="Upload"; // @todo translation
$lang['divers']['up_file']="Upload file"; // @todo translation
$lang['divers']['delqueue']="Delete queue"; // @todo translation
$lang['divers']['replace_file'] = "Do you want to replace the file"; // @todo translation
$lang['access']['workgroup']="Access to the group"; // @todo translation
$lang['workshop_mod']['event_common']='Event common to all workgroups'; // @todo translation
$lang['textbox_js']['placeholder']='Type to receive suggestions.'; // @todo translation

/* system
 ************************/
$lang['divers']['cookies']='Lo sentimos, para modificar estilos las cookies deben estar habilitadas.';
$lang['divers']['redirect_string']='Usted será redireccionado a %s en %d segundos.';
$lang['divers']['sql_connect_failed']='Fallo en la conexión al servidor SQL';
$lang['divers']['db_connect_failed']='Fallo en la conexión a la base de datos';
$lang['divers']['sql_query_failed']='Fallo en la consulta SQL';
$lang['alert']['cookie_disabled']='Your browser does not accept cookies. Please enable cookies to log-in.'; // @todo translation
$lang['filemanager']['browse']="Browse Filemanager"; // @todo translation
/*
 * Messages
 */
$lang['msg']['update_successful']='Update successful.'; // @todo translation
$lang['msg']['update_failed']='Update failed.'; // @todo translation
$lang['msg']['action_not_allowed']='Action not allowed.'; // @todo translation

/*	security
 *  	*/
$lang['antispam']['info']="Anti-spam";
$lang['security']['info']="Por favor, por razones de seguridad introduzca el código aquí";
$lang['security']['info2']="Por favor, copie el código en el campo asociado";
$lang['security']['message']="¡Código de seguridad incorrecto!. Atención, el código es sensible a las mayúsculas.";


/*	aide
 *  	*/
$lang['help']['name']="Ayuda";
$lang['help']['title']="¿Necesita ayuda? haga click";
$lang['help']['img']="¿Necesita ayuda? haga click";
$lang['help']['contact']="Para cualquier cuestión relativa a la administración de Linea21";
$lang['help']['support']="póngase en contacto con el soporte informático";

/*	interface publique
 *  	*/
$lang['groups']['mine']="Mis grupos";
$lang['groups']['his']="Sus groups";
$lang['divers']['level']="Nivel ";
$lang['divers']['scale']="Escala ";
$lang['divers']['themeref']="Área temática ";

$lang['divers']['priority_choice']="Mostrar por prioridad ";
$lang['divers']['level_choice']="Mostrar por nivel ";
$lang['divers']['scale_choice']="Mostrar por escala ";
$lang['divers']['themeref_choice']="Mostrar por área ";
$lang['divers']['actu_left']="Últimas noticias";
$lang['divers']['sdi_left']="Últimos indicadores";
$lang['divers']['contact']="Contacto";
$lang['divers']['accessibility']="Accesibilidad";
$lang['divers']['print']="Imprimir";

$lang['divers']['sousthemeref']="Sub-área temática ";
$lang['divers']['trialpha']="ordenado alfabéticamente";
$lang['divers']['nodata']="No hay datos disponibles";
$lang['divers']['newsletter_public_comment']='Subscríbase al boletín y recibirá la información más actualizada en su buzón de correo';

/*	check date
 *  	*/
$lang['date']['not_valid'] = 'La fecha introducida no es correcta (formato : '. DATE_FORMAT.')';
$lang['date']['date_do_not_exist'] = 'La fecha introducida no existe';
$lang['date']['do_provide'] = 'Please, enter a date.'; // @todo translation

/*	authentification
 *  	*/
$lang['divers']['auth']="Iniciar sesión";
$lang['divers']['myprofile']="Mi cuenta";
$lang['divers']['noauth']="No ha iniciado la sesión";
$lang['divers']['creaauth']="Para registrarse o crear una cuenta";
$lang['divers']['errorauth']="Ha habido un problema en el proceso de autenticación. Por favor, inténtelo de nuevo.";
$lang['divers']['user_inscription']="Registrarse";
$lang['divers']['user_inscription_title']="Crear una cuenta";
$lang['divers']['login']="Usuario";
$lang['divers']['password']="Contraseña";
$lang['divers']['email']="Email";
$lang['divers']['errorauth']="El usuario o la contraseña introducidos son incorrectos";
$lang['auth']['forgot_password']="Forgot your password?"; // @todo translation
$lang['divers']['errorauthadmin']="No dispone de derechos de administración en este módulo";
$lang['newsletter']['unsubscribe']= 'No subscrito';
$lang['auth']['no_user']="<em>%s</em> is not known as a valid user"; // @todo translation
$lang['auth']['sending_mail']="An email has been sent to %s"; // @todo translation
$lang['auth']['note']="To receive a new password, please enter your login."; // @todo translation

/**
 $lang['divers']['auth_mess1']="Para iniciar sesión como administrador(Gestión global del sitio web ) :<br /
 - usuario : admin<br />
 - contraseña : linea<br />
 <br />
 Para iniciar sesión como editor(Gestión de publicaciones, actualizaciones y panel de indicadores) :<br /
 - usuario : admin<br />
 - contraseña : linea<br /><br />";
 */
$lang['divers']['title_login']="Acceso a la consola de administracion de Linea21";
$lang['divers']['auth_mess1']="Para acceder a la consola de administración, debe habilitar las cookies";
$lang['divers']['auth_mess2']="¿Olvidó su contraseña? Contacte con el administrador";

$lang['public']['edito']="Para una mayor transparencia en la comunicación, el software libre Linea21 dispone de un
sistema de gestión de contenidos dedicado al desarrollo sostenible. Este software permite gestionar proyectos,
indicadores, grupos de trabajo y noticias relacionadas con la Agenda 21 Local. <br /><br />Por otra parte,
Linea21 puede servir a los municipios como herramienta de apoyo, tanto en el desarrollo de Agendas 21 como en la gestión de
políticas públicas. Finalmente, Linea21 proporciona a los municipios la oportunidad de comunicarse con los ciudadanos de forma
sencilla, y plantear cuestiones relacionadas con el desarrollo sostenible.<br /><br />";


$lang['public']['workgroup_h1']="Grupos de trabajo";
$lang['public']['workgroup_edito']="Anímese y participe. Le invitamos a formar parte de nuestros grupos de trabajo, en los que podrá debatir sobre diferentes aspectos relacionados con el desarrollo sostenible.";
$lang['public']['dashboard_h1']="Panel de indicadores";
$lang['public']['last_news_h1']="Últimas publicaciones";
$lang['public']['dashboard_edito']="Consulte los últimos valores de los indicadores de sostenibilidad en su municipio. Nuestro panel de indicadores se actualiza periódicamente.";

$lang['check_update']['dl']='La versión %s ya está disponible. Descargar';
$lang['check_update']['ok']='La ultima versión ya se encuentra instalada';
$lang['check_update']['search']='Buscar la versión más reciente';

/**
 * CSS Switcher
 */
$lang['css_switcher']['nostyle'] = 'sin estilos';
$lang['css_switcher']['default'] = 'clásico';
$lang['css_switcher']['minimal'] = 'mínimo';
$lang['css_switcher']['darkstyle'] = 'blanco sobre negro';

/*	nommage des modules autre style blue_linea
 *  	*/
$lang['menu_alt']['general'] = "consola de administracion";
$lang['menu_alt']['theme'] = "áreas tématicas";
$lang['menu_alt']['scale'] = "escalas";
$lang['menu_alt']['level'] = "niveles";
$lang['menu_alt']['user'] = "usuarios";
$lang['menu_alt']['news'] = "noticias";
$lang['menu_alt']['page'] = "pages"; // @todo translation
$lang['menu_alt']['newsletter'] = "boletines";
$lang['menu_alt']['yellowpages'] = "directorio";
$lang['menu_alt']['workshop'] = "grupos de trabajo";
$lang['menu_alt']['publication'] = "publicaciones";
$lang['menu_alt']['sdi'] = "indicadores";
$lang['menu_alt']['project'] = "proyectos";
$lang['menu_alt']['forum'] = "foros";
$lang['menu_alt']['dashboard'] = "panel de indicadores";
$lang['menu_alt']['comment'] = "comentarios";
$lang['menu_alt']['system'] = "configuración";
$lang['menu_alt']['communication'] = "comunicación";
$lang['menu_alt']['suivi_gestion'] = "gestión";
$lang['menu_alt']['configuration'] = "configuración";
$lang['menu_alt']['plugins'] = "plugins";
$lang['menu_alt']['library'] = "mediateca";
$lang['menu_alt']['interface_publique'] = "Ir al sitio web";
$lang['menu_alt']['search_here'] = "Búsqueda...";
$lang['menu_alt']['valid_login'] = "acceder a Linea21";
$lang['menu_alt']['all'] = "en el sitio entero";
$lang['menu_alt']['home'] = "en el sitio entero";
$lang['menu_alt']['home_dashboard'] = "quick admin"; // @todo translation
?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/es/lang_common.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules pour menu
 *  	*/
$lang['menu']['general'] = "Administración global";
$lang['menu']['theme'] = "Gestión de áreas temáticas";
$lang['menu']['scale'] = "Gestión de escalas";
$lang['menu']['level'] = "Gestión de niveles";
$lang['menu']['user'] = "Gestión de usuarios";
$lang['menu']['news'] = "Gestión de noticias";
$lang['menu']['page'] = "Pages manager"; // @todo translation
$lang['menu']['newsletter'] = "Gestión de boletines";
$lang['menu']['yellowpages'] = "Gestión del directorio";
$lang['menu']['workshop'] = "Gestión de grupos de trabajo";
$lang['menu']['publication'] = "Gestión de publicaciones";
$lang['menu']['sdi'] = "Gestión de indicadores";
$lang['menu']['project'] = "Gestión de proyectos";
$lang['menu']['forum'] = "Gestión de foros";
$lang['menu']['comment'] = "Gestión de comentarios";
$lang['menu']['item'] = "Item seleccionado";
$lang['menu']['search'] = "Buscar";
$lang['menu']['advancedsearch'] = "Búsqueda avanzada";
$lang['menu']['dashboard'] = "Gestión del panel de indicadores";
$lang['menu']['system'] = "Configuración del sistema";
$lang['menu']['plugins'] = "Plugins";
$lang['menu']['library'] = "Mediateca";

/*	nommage des modules
 *  	*/
$lang['name']['news_module'] = "noticias";
$lang['name']['newsletter_module'] = "newsletter";
$lang['name']['page_module'] = "page"; // @todo translation
$lang['name']['project_module'] = "project"; // @todo translation
$lang['name']['publication_module'] = "publicación";
$lang['name']['det_publication_module'] = "apartado";
$lang['name']['workshop_module'] = "grupo de trabajo";
$lang['name']['workshoprep_module'] = "informe";
$lang['name']['workshoprepcon_module'] = "sub-informe";
$lang['name']['workshopcal_module'] = "calendario";
$lang['name']['workshopcom_module'] = "asunto";
$lang['name']['sdi_module'] = 'indicador';

/*	nommage header
 *  	*/
$lang['header']['title']= "Linea21, tu consola de administración";
$lang['header']['welcome']= "Bienvenido";
$lang['header']['deconnexion']= "Cerrar sesión";
$lang['header']['deconnexion_title']= "cerrar sesión";
$lang['header']['myaccount']="Mi cuenta";
$lang['header']['myaccount_title']="identificación/acceso a mi cuenta";
$lang['header']['goto_contents']="Ver contenidos";

$lang['admin']['console']="Back-office"; // @todo translation

/*	nommage chemin
 *  	*/
$lang['way']['home']= "Inicio";
$lang['recap']['title']="Resúmen";

/*	action bouton
 *  	*/
$lang['btn']['valid']= "validar";
$lang['btn']['save']= "guardar";
$lang['btn']['annul']= "cancelar";
$lang['btn']['preview']= "revisar valores";
$lang['btn']['read_more']= "→ Read more"; // @todo translation
/*	statut

*  	*/
$lang['statut']['draft']='borrador';
$lang['statut']['draftpdf']='privado';
$lang['statut']['published_on']="fecha de publicación";
$lang['statut']['archived_on']="fecha de modificación";
$lang['statut']['public']="Público";
$lang['statut']['E']="Eliminar";
$lang['statut']['AA']="Archivos privados";
$lang['statut']['PA']="Archivos públicos";
$lang['statut']['W']="Pendiente de ejecución";
$lang['statut']['C']="Cerrado";
$lang['statut']['U']="Usuario";
$lang['statut']['O']="Animador";
$lang['statut']['A']="Administrador";
$lang['statut']['pending']="pending"; // @todo translation

/*	Contact
 *  	*/
$lang['contact']['name']= "Name"; // @todo translation
$lang['contact']['email']="Email"; // @todo translation
$lang['contact']['subject']= "Subject"; // @todo translation
$lang['contact']['body']="Body"; // @todo translation
$lang['contact']['email_error']="<em>%s</em> is not a valid email."; // @todo translation
$lang['contact']['str_error']= "Please fill-up the field <em>%s</em>."; // @todo translation
$lang['contact']['message_sent']="Your message has been sent with success."; // @todo translation
$lang['contact']['contact_us']="Contact us"; // @todo translation

/*	divers
 *  	*/
$lang['divers']['yes']='si';
$lang['divers']['no']='no';
$lang['divers']['nc']='no consta';
$lang['divers']['none']='ninguno';
$lang['divers']['actions']='acciones';
$lang['divers']['no_comment']='sin comentarios';
$lang['divers']['comment']='comentario';
$lang['divers']['optional']='opcional';
$lang['divers']['nodata']='sin datos';
$lang['divers']['novisu']="sin imagen asociada";
$lang['divers']['see_visual']='ver imagen';
$lang['divers']['last_modify']="fecha de carga";
$lang['divers']['date_crea']="fecha de creación";
$lang['divers']['date_sup']="fecha de eliminación";
$lang['divers']['date_publi']="fecha de publicación";
$lang['divers']['sup_confirm']="Confirmar eliminación";
$lang['divers']['statut']="estado";
$lang['divers']['range']="rango";
$lang['divers']['query_result']="Resultado de la consulta";
$lang['divers']['record']="registro";
$lang['divers']['records']="registros";
$lang['divers']['version']="Consola de administración de Linea21: versión ".LINEA_VERSION;
$lang['divers']['select_choice']="-- Seleccionar de la lista--";
$lang['divers']['select_choice2']="-- Seleccionar --";
$lang['divers']['enlarge_photo']='ampliar imagen (hacer click)';
$lang['divers']['by']="por";
$lang['divers']['goto_archives']='Ver archivos';
$lang['divers']['goto_currentlist']='volver al menú principal';
$lang['divers']['page']='página';
$lang['divers']['seconds']='segundos';
$lang['divers']['back_public']='Ir al sitio web';
$lang['divers']['backpage']='Página anterior';
$lang['divers']['licence']='software bajo licencia de %s ';
$lang['divers']['select_all']='seleccionar todo';
$lang['divers']['modify']='Editar';
$lang['divers']['delete']='Eliminar';
$lang['divers']['permalink']='permalink';
$lang['divers']['404']="Esta página no existe!";
$lang['divers']['no_files']="no file"; // @todo translation
$lang['divers']['browse']="Browse ..."; // @todo translation
$lang['divers']['dl']="Download"; // @todo translation
$lang['divers']['up']="Upload"; // @todo translation
$lang['divers']['up_file']="Upload file"; // @todo translation
$lang['divers']['delqueue']="Delete queue"; // @todo translation
$lang['divers']['replace_file'] = "Do you want to replace the file"; // @todo translation
$lang['access']['workgroup']="Access to the group"; // @todo translation
$lang['workshop_mod']['event_common']='Event common to all workgroups'; // @todo translation
$lang['textbox_js']['placeholder']='Type to receive suggestions.'; // @todo translation

/* system
 ************************/
$lang['divers']['cookies']='Lo sentimos, para modificar estilos las cookies deben estar habilitadas.';
$lang['divers']['redirect_string']='Usted será redireccionado a %s en %d segundos.';
$lang['divers']['sql_connect_failed']='Fallo en la conexión al servidor SQL';
$lang['divers']['db_connect_failed']='Fallo en la conexión a la base de datos';
$lang['divers']['sql_query_failed']='Fallo en la consulta SQL';
$lang['alert']['cookie_disabled']='Your browser does not accept cookies. Please enable cookies to log-in.'; // @todo translation
$lang['filemanager']['browse']="Browse Filemanager"; // @todo translation
$lang['common']['select']="Select"; // @todo translation

/*
 * Messages
 */
$lang['msg']['update_successful']='Update successful.'; // @todo translation
$lang['msg']['update_failed']='Update failed.'; // @todo translation
$lang['msg']['action_not_allowed']='Action not allowed.'; // @todo translation

/*
 * Mail
*/
$lang['mail']['header_hello']="Hi,"; // @todo translation
$lang['mail']['footer']="\n<br />Regards.\n<br />"; // @todo translation

/*	security
 *  	*/
$lang['antispam']['info']="Anti-spam";
$lang['security']['info']="Por favor, por razones de seguridad introduzca el código aquí";
$lang['security']['info2']="Por favor, copie el código en el campo asociado";
$lang['security']['message']="¡Código de seguridad incorrecto!. Atención, el código es sensible a las mayúsculas.";


/*	aide
 *  	*/
$lang['help']['name']="Ayuda";
$lang['help']['title']="¿Necesita ayuda? haga click";
$lang['help']['img']="¿Necesita ayuda? haga click";
$lang['help']['contact']="Para cualquier cuestión relativa a la administración de Linea21";
$lang['help']['support']="póngase en contacto con el soporte informático";

/*	interface publique
 *  	*/
$lang['groups']['mine']="Mis grupos";
$lang['groups']['his']="Sus groups";
$lang['divers']['level']="Nivel ";
$lang['divers']['scale']="Escala ";
$lang['divers']['themeref']="Área temática ";

$lang['divers']['priority_choice']="Mostrar por prioridad ";
$lang['divers']['level_choice']="Mostrar por nivel ";
$lang['divers']['scale_choice']="Mostrar por escala ";
$lang['divers']['themeref_choice']="Mostrar por área ";
$lang['divers']['actu_left']="Últimas noticias";
$lang['divers']['sdi_left']="Últimos indicadores";
$lang['divers']['contact']="Contacto";
$lang['divers']['accessibility']="Accesibilidad";
$lang['divers']['print']="Imprimir";

$lang['divers']['sousthemeref']="Sub-área temática ";
$lang['divers']['trialpha']="ordenado alfabéticamente";
$lang['divers']['nodata']="No hay datos disponibles";
$lang['divers']['newsletter_public_comment']='Subscríbase al boletín y recibirá la información más actualizada en su buzón de correo';
$lang['divers']['previous_newsletter']='Previous newsletters';  // @todo translation

/*	check date
 *  	*/
$lang['date']['not_valid'] = 'La fecha introducida no es correcta (formato : '. DATE_FORMAT.')';
$lang['date']['date_do_not_exist'] = 'La fecha introducida no existe';
$lang['date']['do_provide'] = 'Please, enter a date.'; // @todo translation

/*	authentification
 *  	*/
$lang['divers']['auth']="Iniciar sesión";
$lang['divers']['myprofile']="Mi cuenta";
$lang['divers']['noauth']="No ha iniciado la sesión";
$lang['divers']['creaauth']="Para registrarse o crear una cuenta";
$lang['divers']['errorauth']="Ha habido un problema en el proceso de autenticación. Por favor, inténtelo de nuevo.";
$lang['divers']['user_inscription']="Registrarse";
$lang['divers']['user_inscription_title']="Crear una cuenta";
$lang['divers']['login']="Usuario";
$lang['divers']['password']="Contraseña";
$lang['divers']['email']="Email";
$lang['divers']['errorauth']="El usuario o la contraseña introducidos son incorrectos";
$lang['auth']['forgot_password']="Forgot your password?"; // @todo translation
$lang['divers']['errorauthadmin']="No dispone de derechos de administración en este módulo";
$lang['newsletter']['unsubscribe']= 'No subscrito';
$lang['auth']['no_user']="<em>%s</em> is not known as a valid user"; // @todo translation
$lang['auth']['ldap_user']="It seems authentication process rely on LDAP/Active Directory. You are not allowed to change your password on this platform."; // @todo translation
$lang['auth']['sending_mail']="An email has been sent to %s"; // @todo translation
$lang['auth']['note']="To receive a new password, please enter your login."; // @todo translation
$lang['auth']['rememberme']="remember me"; // @todo translation


/**
 $lang['divers']['auth_mess1']="Para iniciar sesión como administrador(Gestión global del sitio web ) :<br /
 - usuario : admin<br />
 - contraseña : linea<br />
 <br />
 Para iniciar sesión como editor(Gestión de publicaciones, actualizaciones y panel de indicadores) :<br /
 - usuario : admin<br />
 - contraseña : linea<br /><br />";
 */
$lang['divers']['title_login']="Acceso a la consola de administracion de Linea21";
$lang['divers']['auth_mess1']="Para acceder a la consola de administración, debe habilitar las cookies";
$lang['divers']['auth_mess2']="¿Olvidó su contraseña? Contacte con el administrador";

$lang['public']['edito']="Para una mayor transparencia en la comunicación, el software libre Linea21 dispone de un
sistema de gestión de contenidos dedicado al desarrollo sostenible. Este software permite gestionar proyectos,
indicadores, grupos de trabajo y noticias relacionadas con la Agenda 21 Local. <br /><br />Por otra parte,
Linea21 puede servir a los municipios como herramienta de apoyo, tanto en el desarrollo de Agendas 21 como en la gestión de
políticas públicas. Finalmente, Linea21 proporciona a los municipios la oportunidad de comunicarse con los ciudadanos de forma
sencilla, y plantear cuestiones relacionadas con el desarrollo sostenible.<br /><br />";


$lang['public']['workgroup_h1']="Grupos de trabajo";
$lang['public']['workgroup_edito']="Anímese y participe. Le invitamos a formar parte de nuestros grupos de trabajo, en los que podrá debatir sobre diferentes aspectos relacionados con el desarrollo sostenible.";
$lang['public']['dashboard_h1']="Panel de indicadores";
$lang['public']['last_news_h1']="Últimas publicaciones";
$lang['public']['dashboard_edito']="Consulte los últimos valores de los indicadores de sostenibilidad en su municipio. Nuestro panel de indicadores se actualiza periódicamente.";

$lang['check_update']['dl']='La versión %s ya está disponible. Descargar';
$lang['check_update']['ok']='La ultima versión ya se encuentra instalada';
$lang['check_update']['search']='Buscar la versión más reciente';

/*	nommage des modules autre style blue_linea
 *  	*/
$lang['menu_alt']['general'] = "consola de administracion";
$lang['menu_alt']['theme'] = "áreas tématicas";
$lang['menu_alt']['scale'] = "escalas";
$lang['menu_alt']['level'] = "niveles";
$lang['menu_alt']['user'] = "usuarios";
$lang['menu_alt']['news'] = "noticias";
$lang['menu_alt']['page'] = "pages"; // @todo translation
$lang['menu_alt']['newsletter'] = "boletines";
$lang['menu_alt']['yellowpages'] = "directorio";
$lang['menu_alt']['workshop'] = "grupos de trabajo";
$lang['menu_alt']['publication'] = "publicaciones";
$lang['menu_alt']['sdi'] = "indicadores";
$lang['menu_alt']['project'] = "proyectos";
$lang['menu_alt']['forum'] = "foros";
$lang['menu_alt']['dashboard'] = "panel de indicadores";
$lang['menu_alt']['comment'] = "comentarios";
$lang['menu_alt']['system'] = "configuración";
$lang['menu_alt']['communication'] = "comunicación";
$lang['menu_alt']['suivi_gestion'] = "gestión";
$lang['menu_alt']['configuration'] = "configuración";
$lang['menu_alt']['plugins'] = "plugins";
$lang['menu_alt']['library'] = "mediateca";
$lang['menu_alt']['interface_publique'] = "Ir al sitio web";
$lang['menu_alt']['search_here'] = "Búsqueda...";
$lang['menu_alt']['valid_login'] = "acceder a Linea21";
$lang['menu_alt']['all'] = "en el sitio entero";
$lang['menu_alt']['home'] = "en el sitio entero";
$lang['menu_alt']['home_dashboard'] = "quick admin"; // @todo translation
?>
